summaryrefslogtreecommitdiffstats
path: root/khtml/rendering
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
commit9c49a74a165b8535c28ccbb2fad37334989b2fc7 (patch)
treef1d72ed61fc64441880b26359d03c58f78b95ada /khtml/rendering
parent42037fa1562f00d75f02d019c039d51b2c27cc6f (diff)
downloadtdelibs-9c49a74a165b8535c28ccbb2fad37334989b2fc7.tar.gz
tdelibs-9c49a74a165b8535c28ccbb2fad37334989b2fc7.zip
Rename incorrect instances of tqrepaint[...] to repaint[...]
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1240369 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/rendering')
-rw-r--r--khtml/rendering/bidi.cpp2
-rw-r--r--khtml/rendering/render_block.cpp4
-rw-r--r--khtml/rendering/render_box.cpp10
-rw-r--r--khtml/rendering/render_box.h2
-rw-r--r--khtml/rendering/render_canvas.cpp10
-rw-r--r--khtml/rendering/render_canvas.h4
-rw-r--r--khtml/rendering/render_container.cpp2
-rw-r--r--khtml/rendering/render_flow.cpp4
-rw-r--r--khtml/rendering/render_form.cpp2
-rw-r--r--khtml/rendering/render_image.cpp4
-rw-r--r--khtml/rendering/render_layer.cpp6
-rw-r--r--khtml/rendering/render_list.cpp2
-rw-r--r--khtml/rendering/render_object.cpp6
-rw-r--r--khtml/rendering/render_object.h4
-rw-r--r--khtml/rendering/render_table.cpp8
-rw-r--r--khtml/rendering/render_table.h2
16 files changed, 36 insertions, 36 deletions
diff --git a/khtml/rendering/bidi.cpp b/khtml/rendering/bidi.cpp
index cc60c5588..f2e64b5f8 100644
--- a/khtml/rendering/bidi.cpp
+++ b/khtml/rendering/bidi.cpp
@@ -1360,7 +1360,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int breakBeforeLin
RenderObject *o = first( this, bidi, false );
while ( o ) {
if (o->markedForRepaint()) {
- o->tqrepaintDuringLayout();
+ o->repaintDuringLayout();
o->setMarkedForRepaint(false);
}
if (o->isReplaced() || o->isFloating() || o->isPositioned()) {
diff --git a/khtml/rendering/render_block.cpp b/khtml/rendering/render_block.cpp
index 764eecb55..5b30e2a58 100644
--- a/khtml/rendering/render_block.cpp
+++ b/khtml/rendering/render_block.cpp
@@ -635,7 +635,7 @@ void RenderBlock::layoutBlock(bool relayoutChildren)
}
if (markedForRepaint()) {
- tqrepaintDuringLayout();
+ repaintDuringLayout();
setMarkedForRepaint(false);
}
@@ -1581,7 +1581,7 @@ void RenderBlock::layoutPositionedObjects(bool relayoutChildren)
for ( ; (r = it.current()); ++it ) {
//kdDebug(6040) << " have a positioned object" << endl;
if (r->markedForRepaint()) {
- r->tqrepaintDuringLayout();
+ r->repaintDuringLayout();
r->setMarkedForRepaint(false);
}
if ( relayoutChildren || r->style()->position() == FIXED ||
diff --git a/khtml/rendering/render_box.cpp b/khtml/rendering/render_box.cpp
index e558352af..e63115361 100644
--- a/khtml/rendering/render_box.cpp
+++ b/khtml/rendering/render_box.cpp
@@ -806,17 +806,17 @@ void RenderBox::tqrepaint(Priority prior)
p = p->parent();
int xoff = p->hasOverflowClip() ? 0 : p->overflowLeft();
int yoff = p->hasOverflowClip() ? 0 : p->overflowTop();
- p->tqrepaintRectangle( -ow + xoff, -ow + yoff, p->effectiveWidth()+ow*2, p->effectiveHeight()+ow*2, prior);
+ p->repaintRectangle( -ow + xoff, -ow + yoff, p->effectiveWidth()+ow*2, p->effectiveHeight()+ow*2, prior);
}
else
{
int xoff = hasOverflowClip() ? 0 : overflowLeft();
int yoff = hasOverflowClip() ? 0 : overflowTop();
- tqrepaintRectangle( -ow + xoff, -ow + yoff, effectiveWidth()+ow*2, effectiveHeight()+ow*2, prior);
+ repaintRectangle( -ow + xoff, -ow + yoff, effectiveWidth()+ow*2, effectiveHeight()+ow*2, prior);
}
}
-void RenderBox::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool f)
+void RenderBox::repaintRectangle(int x, int y, int w, int h, Priority p, bool f)
{
x += m_x;
y += m_y;
@@ -830,7 +830,7 @@ void RenderBox::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool
if (style()->position() == FIXED) f=true;
- // kdDebug( 6040 ) << "RenderBox(" <<this << ", " << renderName() << ")::tqrepaintRectangle (" << x << "/" << y << ") (" << w << "/" << h << ")" << endl;
+ // kdDebug( 6040 ) << "RenderBox(" <<this << ", " << renderName() << ")::repaintRectangle (" << x << "/" << y << ") (" << w << "/" << h << ")" << endl;
RenderObject *o = container();
if( o ) {
if (o->layer()) {
@@ -839,7 +839,7 @@ void RenderBox::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool
if (style()->position() == ABSOLUTE)
o->layer()->checkInlineRelOffset(this,x,y);
}
- o->tqrepaintRectangle(x, y, w, h, p, f);
+ o->repaintRectangle(x, y, w, h, p, f);
}
}
diff --git a/khtml/rendering/render_box.h b/khtml/rendering/render_box.h
index 8158d6037..78b85b5f4 100644
--- a/khtml/rendering/render_box.h
+++ b/khtml/rendering/render_box.h
@@ -89,7 +89,7 @@ public:
virtual void tqrepaint(Priority p=NormalPriority);
- virtual void tqrepaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
+ virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual short containingBlockWidth() const;
void relativePositionOffset(int &tx, int &ty) const;
diff --git a/khtml/rendering/render_canvas.h b/khtml/rendering/render_canvas.h
index 82b59705b..f2822bc94 100644
--- a/khtml/rendering/render_canvas.h
+++ b/khtml/rendering/render_canvas.h
@@ -62,8 +62,8 @@ public:
KHTMLView *view() const { return m_view; }
virtual void tqrepaint(Priority p=NormalPriority);
- virtual void tqrepaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
- void tqrepaintViewRectangle(int x, int y, int w, int h, bool asap=false);
+ virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
+ void repaintViewRectangle(int x, int y, int w, int h, bool asap=false);
bool needsFullRepaint() const;
void deferredRepaint( RenderObject* o );
void scheduleDeferredRepaints();
diff --git a/khtml/rendering/render_container.cpp b/khtml/rendering/render_container.cpp
index 45cfc5729..13f17c08d 100644
--- a/khtml/rendering/render_container.cpp
+++ b/khtml/rendering/render_container.cpp
@@ -171,7 +171,7 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
// So that we'll get the appropriate dirty bit set (either that a normal flow child got yanked or
// that a positioned child got yanked). We also tqrepaint, so that the area exposed when the child
- // disappears gets tqrepainted properly.
+ // disappears gets repainted properly.
if ( document()->renderer() ) {
oldChild->setNeedsLayoutAndMinMaxRecalc();
oldChild->tqrepaint();
diff --git a/khtml/rendering/render_flow.cpp b/khtml/rendering/render_flow.cpp
index 2d56e8f40..97dd40468 100644
--- a/khtml/rendering/render_flow.cpp
+++ b/khtml/rendering/render_flow.cpp
@@ -295,14 +295,14 @@ void RenderFlow::tqrepaint(Priority prior)
}
RootInlineBox *lastRoot = lastLineBox() && !needsLayout() ? lastLineBox()->root() : 0;
- containingBlock()->tqrepaintRectangle(-ow+left, -ow+top,
+ containingBlock()->repaintRectangle(-ow+left, -ow+top,
width()+ow*2,
(lastRoot ? lastRoot->bottomOverflow() - top : height())+ow*2, prior);
}
else {
if (firstLineBox() && firstLineBox()->topOverflow() < 0) {
int ow = style() ? style()->outlineSize() : 0;
- tqrepaintRectangle(-ow, -ow+firstLineBox()->topOverflow(),
+ repaintRectangle(-ow, -ow+firstLineBox()->topOverflow(),
effectiveWidth()+ow*2, effectiveHeight()+ow*2, prior);
}
else
diff --git a/khtml/rendering/render_form.cpp b/khtml/rendering/render_form.cpp
index de87072d1..a83c1788e 100644
--- a/khtml/rendering/render_form.cpp
+++ b/khtml/rendering/render_form.cpp
@@ -1450,7 +1450,7 @@ void TextAreaWidget::slotReplaceNext()
if (!(m_replace->options() & KReplaceDialog::PromptOnReplace)) {
viewport()->tqsetUpdatesEnabled(true);
- tqrepaintChanged();
+ repaintChanged();
}
if (res == KFind::NoMatch) { // at end
diff --git a/khtml/rendering/render_image.cpp b/khtml/rendering/render_image.cpp
index 1cd79eb55..b5357bba1 100644
--- a/khtml/rendering/render_image.cpp
+++ b/khtml/rendering/render_image.cpp
@@ -196,10 +196,10 @@ void RenderImage::setPixmap( const TQPixmap &p, const TQRect& r, CachedImage *o)
resizeCache = TQPixmap(); // for resized animations
if(completeRepaint)
- tqrepaintRectangle(borderLeft()+paddingLeft(), borderTop()+paddingTop(), contentWidth(), contentHeight());
+ repaintRectangle(borderLeft()+paddingLeft(), borderTop()+paddingTop(), contentWidth(), contentHeight());
else
{
- tqrepaintRectangle(r.x() + borderLeft() + paddingLeft(), r.y() + borderTop() + paddingTop(),
+ repaintRectangle(r.x() + borderLeft() + paddingLeft(), r.y() + borderTop() + paddingTop(),
r.width(), r.height());
}
}
diff --git a/khtml/rendering/render_layer.cpp b/khtml/rendering/render_layer.cpp
index 6c04079d9..3427bf1dc 100644
--- a/khtml/rendering/render_layer.cpp
+++ b/khtml/rendering/render_layer.cpp
@@ -205,7 +205,7 @@ void RenderLayer::tqrepaint( Priority p, bool markForRepaint )
calculateRects(renderer()->canvas()->layer(), renderer()->viewRect(), layerBounds, damageRect, fgrect);
m_visibleRect = damageRect.intersect( layerBounds );
if (m_visibleRect.isValid())
- renderer()->canvas()->tqrepaintViewRectangle( m_visibleRect.x(), m_visibleRect.y(), m_visibleRect.width(), m_visibleRect.height(), (p > NormalPriority) );
+ renderer()->canvas()->repaintViewRectangle( m_visibleRect.x(), m_visibleRect.y(), m_visibleRect.width(), m_visibleRect.height(), (p > NormalPriority) );
if (markForRepaint)
m_markedForRepaint = true;
}
@@ -233,14 +233,14 @@ void RenderLayer::updateLayerPositions(RenderLayer* rootLayer, bool doFullRepain
#ifdef APPLE_CHANGES
// FIXME: Child object could override visibility.
if (checkForRepaint && (m_object->style()->visibility() == VISIBLE))
- m_object->tqrepaintAfterLayoutIfNeeded(m_tqrepaintRect, m_fullRepaintRect);
+ m_object->repaintAfterLayoutIfNeeded(m_repaintRect, m_fullRepaintRect);
#else
if (checkForRepaint && m_markedForRepaint) {
TQRect layerBounds, damageRect, fgrect;
calculateRects(rootLayer, renderer()->viewRect(), layerBounds, damageRect, fgrect);
TQRect vr = damageRect.intersect( layerBounds );
if (vr != m_visibleRect && vr.isValid()) {
- renderer()->canvas()->tqrepaintViewRectangle( vr.x(), vr.y(), vr.width(), vr.height() );
+ renderer()->canvas()->repaintViewRectangle( vr.x(), vr.y(), vr.width(), vr.height() );
m_visibleRect = vr;
}
}
diff --git a/khtml/rendering/render_list.cpp b/khtml/rendering/render_list.cpp
index 515283f8b..c88f103d3 100644
--- a/khtml/rendering/render_list.cpp
+++ b/khtml/rendering/render_list.cpp
@@ -387,7 +387,7 @@ void RenderListMarker::setPixmap( const TQPixmap &p, const TQRect& r, CachedImag
if(m_width != m_listImage->pixmap_size().width() || m_height != m_listImage->pixmap_size().height())
setNeedsLayoutAndMinMaxRecalc();
else
- tqrepaintRectangle(0, 0, m_width, m_height);
+ repaintRectangle(0, 0, m_width, m_height);
}
void RenderListMarker::calcMinMaxWidth()
diff --git a/khtml/rendering/render_object.cpp b/khtml/rendering/render_object.cpp
index 999bded25..89adbf548 100644
--- a/khtml/rendering/render_object.cpp
+++ b/khtml/rendering/render_object.cpp
@@ -1103,9 +1103,9 @@ void RenderObject::paint( PaintInfo&, int /*tx*/, int /*ty*/)
{
}
-void RenderObject::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool f)
+void RenderObject::repaintRectangle(int x, int y, int w, int h, Priority p, bool f)
{
- if(parent()) parent()->tqrepaintRectangle(x, y, w, h, p, f);
+ if(parent()) parent()->repaintRectangle(x, y, w, h, p, f);
}
#ifdef ENABLE_DUMP
@@ -1423,7 +1423,7 @@ void RenderObject::dirtyFormattingContext( bool checkContainer )
m_parent->dirtyFormattingContext(false);
}
-void RenderObject::tqrepaintDuringLayout()
+void RenderObject::repaintDuringLayout()
{
if (canvas()->needsFullRepaint() || isText())
return;
diff --git a/khtml/rendering/render_object.h b/khtml/rendering/render_object.h
index 2e67807c3..49e9065e4 100644
--- a/khtml/rendering/render_object.h
+++ b/khtml/rendering/render_object.h
@@ -327,7 +327,7 @@ public:
void setOverhangingContents(bool p=true);
void markContainingBlocksForLayout();
void dirtyFormattingContext( bool checkContainer );
- void tqrepaintDuringLayout();
+ void repaintDuringLayout();
void setNeedsLayout(bool b, bool markParents = true);
void setChildNeedsLayout(bool b, bool markParents = true);
void setMinMaxKnown(bool b=true) {
@@ -683,7 +683,7 @@ public:
// force a complete tqrepaint
virtual void tqrepaint(Priority p = NormalPriority) { if(m_parent) m_parent->tqrepaint(p); }
- virtual void tqrepaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
+ virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual unsigned int length() const { return 1; }
diff --git a/khtml/rendering/render_table.cpp b/khtml/rendering/render_table.cpp
index 1910a90e4..337e9399d 100644
--- a/khtml/rendering/render_table.cpp
+++ b/khtml/rendering/render_table.cpp
@@ -277,7 +277,7 @@ void RenderTable::layout()
}
if (markedForRepaint()) {
- tqrepaintDuringLayout();
+ repaintDuringLayout();
setMarkedForRepaint(false);
}
@@ -1306,7 +1306,7 @@ int RenderTableSection::layoutRows( int toAdd )
m_width = table()->contentWidth();
if (markedForRepaint()) {
- tqrepaintDuringLayout();
+ repaintDuringLayout();
setMarkedForRepaint(false);
}
@@ -2319,9 +2319,9 @@ bool RenderTableCell::requiresLayer() const {
return /* style()->opacity() < 1.0f || */ hasOverflowClip() || isRelPositioned();
}
-void RenderTableCell::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool f)
+void RenderTableCell::repaintRectangle(int x, int y, int w, int h, Priority p, bool f)
{
- RenderBlock::tqrepaintRectangle(x, y, w, h + _topExtra + _bottomExtra, p, f);
+ RenderBlock::repaintRectangle(x, y, w, h + _topExtra + _bottomExtra, p, f);
}
bool RenderTableCell::absolutePosition(int &xPos, int &yPos, bool f) const
diff --git a/khtml/rendering/render_table.h b/khtml/rendering/render_table.h
index b620b512c..a6de6cfaf 100644
--- a/khtml/rendering/render_table.h
+++ b/khtml/rendering/render_table.h
@@ -396,7 +396,7 @@ public:
// lie position to outside observers
virtual int yPos() const { return m_y + _topExtra; }
- virtual void tqrepaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
+ virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual bool absolutePosition(int &xPos, int &yPos, bool f = false) const;
virtual short baselinePosition( bool = false ) const;
diff --git a/khtml/rendering/render_canvas.cpp b/khtml/rendering/render_canvas.cpp
index c06f9f15d..3980c8eee 100644
--- a/khtml/rendering/render_canvas.cpp
+++ b/khtml/rendering/render_canvas.cpp
@@ -269,7 +269,7 @@ bool RenderCanvas::needsFullRepaint() const
return m_needsFullRepaint || m_pagedMode;
}
-void RenderCanvas::tqrepaintViewRectangle(int x, int y, int w, int h, bool asap)
+void RenderCanvas::repaintViewRectangle(int x, int y, int w, int h, bool asap)
{
KHTMLAssert( view() );
view()->scheduleRepaint( x, y, w, h, asap );
@@ -332,7 +332,7 @@ void RenderCanvas::paintBoxDecorations(PaintInfo& paintInfo, int /*_tx*/, int /*
paintInfo.p->fillRect(paintInfo.r, view()->tqpalette().active().color(TQColorGroup::Base));
}
-void RenderCanvas::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bool f)
+void RenderCanvas::repaintRectangle(int x, int y, int w, int h, Priority p, bool f)
{
if (m_staticMode) return;
// kdDebug( 6040 ) << "updating views contents (" << x << "/" << y << ") (" << w << "/" << h << ")" << endl;
@@ -353,7 +353,7 @@ void RenderCanvas::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bo
if (p == RealtimePriority)
// ### KWQ's updateContents has an additional parameter "now".
// It's not clear what the difference between updateContents(...,true)
// and tqrepaintContents(...) is. As Qt doesn't have this, I'm leaving it out. (LS)
m_view->updateContents(ur/*, true*/);
else if (p == HighPriority)
m_view->scheduleRepaint(x, y, w, h, true /*asap*/);
@@ -374,7 +374,7 @@ void RenderCanvas::scheduleDeferredRepaints()
for ( it = m_dirtyChildren.begin(); it != m_dirtyChildren.end(); ++it )
(*it)->tqrepaint();
}
- //kdDebug(6040) << "scheduled deferred tqrepaints: " << m_dirtyChildren.count() << " needed full tqrepaint: " << needsFullRepaint() << endl;
+ //kdDebug(6040) << "scheduled deferred repaints: " << m_dirtyChildren.count() << " needed full tqrepaint: " << needsFullRepaint() << endl;
m_dirtyChildren.clear();
}
@@ -388,7 +388,7 @@ void RenderCanvas::tqrepaint(Priority p)
m_view->scheduleRelayout();
return;
}
// ### same as in tqrepaintRectangle
m_view->updateContents(m_view->contentsX(), m_view->contentsY(),
m_view->visibleWidth(), m_view->visibleHeight()/*, true*/);
}
@@ -353,7 +353,7 @@ void RenderCanvas::tqrepaintRectangle(int x, int y, int w, int h, Priority p, bo
// ### KWQ's updateContents has an additional parameter "now".
// It's not clear what the difference between updateContents(...,true)
- // and tqrepaintContents(...) is. As Qt doesn't have this, I'm leaving it out. (LS)
+ // and repaintContents(...) is. As Qt doesn't have this, I'm leaving it out. (LS)
m_view->updateContents(ur/*, true*/);
else if (p == HighPriority)
@@ -388,7 +388,7 @@ void RenderCanvas::tqrepaint(Priority p)
return;
}
- // ### same as in tqrepaintRectangle
+ // ### same as in repaintRectangle
m_view->updateContents(m_view->contentsX(), m_view->contentsY(),
m_view->visibleWidth(), m_view->visibleHeight()/*, true*/);